@@ -87,7 +87,8 @@ authorization <- function(authorization) {
 #' @keywords internal
 .check_auth <- function() {
   if (is.null(.genesysEnv$Authorization)) {
-    warning("You must first authorize with Genesys with user_login() or client_login(...).");
+    message("You must first authorize with Genesys with user_login() or client_login(...).")
+    stop("You must first authorize with Genesys with user_login() or client_login(...).", call. = FALSE);
   }
 }
 
@@ -96,9 +97,8 @@ authorization <- function(authorization) {
 #'
 #' The authorization URL will open in a browser, ask the user to grant
 #' permissions to R.
-#' 
-#' ```
-#' 
+#'
+#'
 #' After successful authentication the browser will display the message:
 #' "Authentication complete. Please close this page and return to R."
 #' 
@@ -108,6 +108,7 @@ authorization <- function(authorization) {
 #'                     This is most useful if the default port is blocked and you wish to specify
 #'                     another port: `redirect_uri = "http://127.0.0.1:44211"`.
 #'                     Note that using `http://localhost` will not work.
+#'
 #' @seealso \code{\link{setup}}
 #'
 #' @importFrom httr2 oauth_client oauth_flow_auth_code
@@ -197,21 +198,6 @@ client_login <- function() {
   return(resp)
 }
 
-
-#' Get partial API v1 URL for the provided path
-#'
-#' @param path relative path of the API v1 endpoint (e.g. \code{/me})
-#'
-#' @return Returns "/api/v1" + path
-#' @export
-#'
-#' @examples
-#'  api1_url("/me")
-api1_url <- function(path) {
-  paste0("/api/v1", path)
-}
-
-
 #' Get partial API v2 URL for the provided path
 #'
 #' @param path relative path of the API v2 endpoint (e.g. \code{/me})
@@ -251,3 +237,27 @@ api2_url <- function(path) {
 
   resp
 }
+
+#' HTTP POST method
+#'
+#' @param path API path
+#' @param query query string parameters
+#' @param accept Content type to use in Accept header
+#' @param ... parameters to submit in form body
+#'
+#' @return httr response
+#' @keywords internal
+.postForm <- function(path, query = NULL, accept = "application/json", ...) {
+
+  # print(paste("Body is:", ...))
+  req <- .api_request(path = path, method = "post", accept = accept, query = query, body = NULL, content.type = "application/x-www-form-urlencoded");
+
+  resp <- req %>%
+    httr2::req_body_multipart(...) %>% # All extra arguments are set as form body
+    httr2::req_perform(verbosity = 0) # Set verbosity to 3 for debugging
+
+  if (httr2::resp_has_body(resp))
+    return(httr2::resp_body_string(resp, encoding = "UTF8"))
+  else
+    return("")
+}
